==> BEAR-0.9.23.tgz: BEAR-0.9.23/BEAR/Emoji/Conf/Softbank.php <==
<?php
/**
 * BEAR
 *
 * PHP versions 5
 *
 * @category   BEAR
 * @package    BEAR_Emoji
 * @author     Akihito Koriyama <koriyama@bear-project.net>
 * @copyright  2008-2011 Akihito Koriyama All rights reserved.
 * @license    http://opensource.org/licenses/bsd-license.php BSD
 * @version    SVN: Release: @package_version@ $Id:$
 * @link       http://www.bear-project.net/
 */

/**
 * スタティック絵文字データ for Softbank
 */
$emojiChars = array(
    'SUN' => '$Gj',
    'CLOUD' => '$Gi',
    'RAIN' => '$Gk',
    'SNOW' => '$Gh',
    'THUNDER' => '$E]',
    'TYPHOON' => '$Pc',
    'FOG' => '&#63653;',
    'DRIZZLE' => '$P\\',
    'ARIES' => '$F_',
    'TAURUS' => '$F`',
    'GEMINI' => '$Fa',
    'CANCER' => '$Fb',
    'LEO' => '$Fc',
    'VIRGO' => '$Fd',
    'LIBRA' => '$Fe',
    'SCORPIO' => '$Ff',
    'SAGITTARIUS' => '$Fg',
    'CAPRICORN' => '$Fh',
    'AQUARIUS' => '$Fi',
    'PISCES' => '$Fj',
    'SPORTS1' => '&#63667;',
    'BASEBALL' => '$G6',
    'GOLF' => '$G4',
    'TENNIS' => '$G5',
    'SOCCER' => '$G8',
    'SKIING' => '$G3',
    'BASKETBALL' => '$PJ',
    'MOTORSPORTS' => '$ER',
    'POKEBERU' => '&#63675;',
    'TRAIN' => '$G>',
    'SUBWAY' => '$PT',
    'SHINKANSEN' => '$PU',
    'CAR1' => '$G;',
    'CAR2' => '$PN',
    'BUS' => '$Ey',
    'SHIP' => '$F"',
    'PLAIN' => '$G=',
    'HOME' => '$GV',
    'BUILDING' => '$GX',
    'POSTOFFICE' => '$Es',
    'HOSPITAL' => '$Eu',
    'BANK' => '$Em',
    'ATM' => '$Et',
    'HOTEL' => '$Ex',
    'CONVENI' => '$Ev',
    'GAS' => '$GZ',
    'PARKING' => '$Eo',
    'SIGN' => '$En',
    'TOILE' => '$Eq',
    'RESTRAN' => '$Gc',
    'BAR' => '$Gd',
    'BEER' => '$Gg',
    'FASTFOOD' => '$E@',
    'SHOP' => '$E^',
    'SALON' => '$O3',
    'KARAOKE' => '$G\\',
    'MOVIE' => '$G]',
    'YA1' => '$FV',
    'TOYS' => '&#63706;',
    'ENTAME' => '$O*',
    'ART' => '$Q"',
    'PLAY' => '$Q#',
    'EVENT' => '&#63710;',
    'TICKET' => '$EE',
    'SMOKING' => '$O.',
    'NOSMOKING' => '$F(',
    'CAMERA' => '$G(',
    'BAG' => '$OC',
    'BOOK' => '$Eh',
    'RIBBON' => '$O4',
    'PRESENT' => '$E2',
    'BIRTHDAY' => '$Ok',
    'PHONE' => '$G)',
    'MOBILE' => '$G*',
    'MEMO' => '$O!',
    'TV' => '$EJ',
    'GAME' => '&#63724;',
    'CD' => '$EF',
    'HEART1' => '$F,',
    'SPADE' => '$F.',
    'DIAMOND' => '$F-',
    'CLUB' => '$F/',
    'EYE' => '$P9',
    'EAR' => '$P;',
    'HAND1' => '$G0',
    'HAND2' => '$G1',
    'HAND3' => '$G2',
    'YA2' => '$FX',
    'YA3' => '$FW',
    'FOOT' => '$QV',
    'SHOES' => '$G\'',
    'GLASSES' => '&#63739;',
    'WHEELCHAIR' => '$F*',
    'MOON1' => '&#63808;',
    'MOON2' => '$Gl',
    'MOON3' => '$Gl',
    'MOON4' => '$Gl',
    'MOON5' => '&#63812;',
    'DOG' => '$Gr',
    'CAT1' => '$Go',
    'RESORT' => '$G<',
    'CHRISTMAS' => '$GS',
    'YA4' => '$FY',
    'PHONETO' => '$E$',
    'MAILTO' => '$E#',
    'FAXTO' => '$G+',
    'IMODE1' => '&#63861;',
    'IMODE2' => '&#63862;',
    'MAIL' => '$E#',
    'DOCOMO' => '&#63864;',
    'DOCOMOPOINT' => '&#63865;',
    'CHARGE' => '&#63866;',
    'FREE' => '&#63867;',
    'ID' => '$FI',
    'PASSWORD' => '$G_',
    'RETURN' => '&#63870;',
    'CLEAR' => '&#63872;',
    'SEARCH' => '$E4',
    'NEW' => '$F2',
    'GPS' => '&#63875;',
    'FREEDIAL' => '$F1',
    'SHARPDIAL' => '$F0',
    'Q' => '&#63937;',
    'NUM01' => '$F<',
    'NUM02' => '$F=',
    'NUM03' => '$F>',
    'NUM04' => '$F?',
    'NUM05' => '$F@',
    'NUM06' => '$FA',
    'NUM07' => '$FB',
    'NUM08' => '$FC',
    'NUM09' => '$FD',
    'NUM00' => '$FE',
    'OK1' => '$Fm',
    'HEART2' => '$GB',
    'HEART3' => '$OG',
    'HEARTBREAK' => '$GC',
    'HEART4' => '$OG',
    'FACE1' => '$Gw',
    'FACE2' => '$Gy',
    'FACE3' => '$Gx',
    'FACE4' => '$P\'',
    'FACE5' => '$P&',
    'GOOD' => '$FV',
    'ONPU' => '$G^',
    'ONSEN' => '$EC',
    'MIDASHI' => '$F;',
    'KISS' => '$G#',
    'KIRAKIRA' => '$ON',
    'HINT' => '$E/',
    'ANGER' => '$OT',
    'PUNCH' => '$G-',
    'BOMB' => '$O1',
    'MOOD' => '$OF',
    'BAD' => '$FX',
    'SLEEP' => '$E\\',
    'BIKKURI' => '$GA',
    'QUESTION' => '&#63912;',
    'BIKKURI2' => '&#63913;',
    'DON' => '&#63914;',
    'ASE1' => '$OQ',
    'ASE2' => '$OQ',
    'DASH' => '$OP',
    'SIGN1' => '&#63918;',
    'SIGN2' => '&#63919;',
    'CLAPPERBOARD' => '$OD',
    'FUKURO' => '&#63825;',
    'PEN1' => '$O!',
    'SHADOW' => '&#63829;',
    'CHAIR' => '$E?',
    'NIGHT' => '$Pk',
    'SOON' => '&#63835;',
    'ON' => '&#63836;',
    'END' => '&#63837;',
    'SCHEDULE' => '$GM',
    'IAPP1' => '&#63921;',
    'IAPP2' => '&#63922;',
    'TSHIRT' => '$G&',
    'GAMA' => '&#63924;',
    'MAKEUP' => '$O<',
    'ZUBON' => '&#63926;',
    'SPORTS2' => '&#63927;',
    'TIN' => '$OE',
    'DOOR' => '&#63929;',
    'MONEY' => '$EO',
    'PC' => '$G,',
    'HEARTMAIL' => '$E#$OH',
    'TOOL' => '$E6',
    'PEN2' => '$O!',
    'CROWN' => '$E.',
    'RING' => '$GT',
    'WATCH1' => '&#63937;',
    'BICYCLE' => '$EV',
    'CUP' => '$OX',
    'WATCH2' => '&#63940;',
    'FACE6' => '$P#',
    'FACE7' => '$P*',
    'FACE8' => '$P5$OQ',
    'FACE9' => '$E(',
    'FACE10' => '$P6',
    'FACE11' => '$P.',
    'FACE12' => '$E&',
    'OK2' => '$G.',
    'FACE13' => '$E%',
    'FACE14' => '$P%',
    'FACE15' => '$P*',
    'FACE16' => '$P1',
    'CAT2' => '$P"',
    'FACE17' => '$P3',
    'NG' => '&#63956;',
    'CLIP' => '&#63957;',
    'COPYRIGHT' => '$Fn',
    'TM' => '$QW',
    'RUN' => '$E5',
    'MARUHI' => '$O5',
    'UPDATE' => '$FV',
    'R' => '$Fo',
    'ALERT' => '$Fr',
    'KIN' => '&#63965;',
    'AKI' => '$FK',
    'GOU' => '&#63967;',
    'MAN' => '$FJ',
    'YA5' => '&#63969;',
    'YA6' => '&#63970;',
    'SCHOOL' => '$Ew',
    'WAVE' => '$P^',
    'FUJI' => '$G[',
    'FOURLEAF' => '$E0',
    'CHERRY' => '&#63975;',
    'TULIP' => '$O$',
    'BANANA' => '&#63977;',
    'APPLE' => '$Oe',
    'BUD' => '$E0',
    'MOMIJI' => '$E8',
    'SAKURA' => '$GP',
    'ONIGIRI' => '$Ob',
    'CAKE' => '$Gf',
    'TOKURI' => '$O+',
    'DONBURI' => '$O`',
    'BREAD' => '$OY',
    'SNAIL' => '&#63987;',
    'HIYOKO' => '$QC',
    'PENGIN' => '$Gu',
    'FISH' => '$G9',
    'FACE18' => '$Gv',
    'FACE19' => '$P$',
    'HORSE' => '$G:',
    'PIG' => '$E+',
    'WINE' => '$Gd',
    'FACE20' => '$E\''
);

==> BEAR-0.9.24.tgz: BEAR-0.9.24/BEAR/Emoji/Conf/Softbank.php <==
<?php
/**
 * BEAR
 *
 * PHP versions 5
 *
 * @category   BEAR
 * @package    BEAR_Emoji
 * @author     Akihito Koriyama <akihito.koriyama@gmail.com>
 * @copyright  2008-2015 Akihito Koriyama All rights reserved.
 * @license    http://opensource.org/licenses/bsd-license.php BSD
 * @version    @package_version@
 * @link       https://github.com/bearsaturday
 */

/**
 * スタティック絵文字データ for Softbank
 */
$emojiChars = array(
    'SUN' => '$Gj',
    'CLOUD' => '$Gi',
    'RAIN' => '$Gk',
    'SNOW' => '$Gh',
    'THUNDER' => '$E]',
    'TYPHOON' => '$Pc',
    'FOG' => '&#63653;',
    'DRIZZLE' => '$P\\',
    'ARIES' => '$F_',
    'TAURUS' => '$F`',
    'GEMINI' => '$Fa',
    'CANCER' => '$Fb',
    'LEO' => '$Fc',
    'VIRGO' => '$Fd',
    'LIBRA' => '$Fe',
    'SCORPIO' => '$Ff',
    'SAGITTARIUS' => '$Fg',
    'CAPRICORN' => '$Fh',
    'AQUARIUS' => '$Fi',
    'PISCES' => '$Fj',
    'SPORTS1' => '&#63667;',
    'BASEBALL' => '$G6',
    'GOLF' => '$G4',
    'TENNIS' => '$G5',
    'SOCCER' => '$G8',
    'SKIING' => '$G3',
    'BASKETBALL' => '$PJ',
    'MOTORSPORTS' => '$ER',
    'POKEBERU' => '&#63675;',
    'TRAIN' => '$G>',
    'SUBWAY' => '$PT',
    'SHINKANSEN' => '$PU',
    'CAR1' => '$G;',
    'CAR2' => '$PN',
    'BUS' => '$Ey',
    'SHIP' => '$F"',
    'PLAIN' => '$G=',
    'HOME' => '$GV',
    'BUILDING' => '$GX',
    'POSTOFFICE' => '$Es',
    'HOSPITAL' => '$Eu',
    'BANK' => '$Em',
    'ATM' => '$Et',
    'HOTEL' => '$Ex',
    'CONVENI' => '$Ev',
    'GAS' => '$GZ',
    'PARKING' => '$Eo',
    'SIGN' => '$En',
    'TOILE' => '$Eq',
    'RESTRAN' => '$Gc',
    'BAR' => '$Gd',
    'BEER' => '$Gg',
    'FASTFOOD' => '$E@',
    'SHOP' => '$E^',
    'SALON' => '$O3',
    'KARAOKE' => '$G\\',
    'MOVIE' => '$G]',
    'YA1' => '$FV',
    'TOYS' => '&#63706;',
    'ENTAME' => '$O*',
    'ART' => '$Q"',
    'PLAY' => '$Q#',
    'EVENT' => '&#63710;',
    'TICKET' => '$EE',
    'SMOKING' => '$O.',
    'NOSMOKING' => '$F(',
    'CAMERA' => '$G(',
    'BAG' => '$OC',
    'BOOK' => '$Eh',
    'RIBBON' => '$O4',
    'PRESENT' => '$E2',
    'BIRTHDAY' => '$Ok',
    'PHONE' => '$G)',
    'MOBILE' => '$G*',
    'MEMO' => '$O!',
    'TV' => '$EJ',
    'GAME' => '&#63724;',
    'CD' => '$EF',
    'HEART1' => '$F,',
    'SPADE' => '$F.',
    'DIAMOND' => '$F-',
    'CLUB' => '$F/',
    'EYE' => '$P9',
    'EAR' => '$P;',
    'HAND1' => '$G0',
    'HAND2' => '$G1',
    'HAND3' => '$G2',
    'YA2' => '$FX',
    'YA3' => '$FW',
    'FOOT' => '$QV',
    'SHOES' => '$G\'',
    'GLASSES' => '&#63739;',
    'WHEELCHAIR' => '$F*',
    'MOON1' => '&#63808;',
    'MOON2' => '$Gl',
    'MOON3' => '$Gl',
    'MOON4' => '$Gl',
    'MOON5' => '&#63812;',
    'DOG' => '$Gr',
    'CAT1' => '$Go',
    'RESORT' => '$G<',
    'CHRISTMAS' => '$GS',
    'YA4' => '$FY',
    'PHONETO' => '$E$',
    'MAILTO' => '$E#',
    'FAXTO' => '$G+',
    'IMODE1' => '&#63861;',
    'IMODE2' => '&#63862;',
    'MAIL' => '$E#',
    'DOCOMO' => '&#63864;',
    'DOCOMOPOINT' => '&#63865;',
    'CHARGE' => '&#63866;',
    'FREE' => '&#63867;',
    'ID' => '$FI',
    'PASSWORD' => '$G_',
    'RETURN' => '&#63870;',
    'CLEAR' => '&#63872;',
    'SEARCH' => '$E4',
    'NEW' => '$F2',
    'GPS' => '&#63875;',
    'FREEDIAL' => '$F1',
    'SHARPDIAL' => '$F0',
    'Q' => '&#63937;',
    'NUM01' => '$F<',
    'NUM02' => '$F=',
    'NUM03' => '$F>',
    'NUM04' => '$F?',
    'NUM05' => '$F@',
    'NUM06' => '$FA',
    'NUM07' => '$FB',
    'NUM08' => '$FC',
    'NUM09' => '$FD',
    'NUM00' => '$FE',
    'OK1' => '$Fm',
    'HEART2' => '$GB',
    'HEART3' => '$OG',
    'HEARTBREAK' => '$GC',
    'HEART4' => '$OG',
    'FACE1' => '$Gw',
    'FACE2' => '$Gy',
    'FACE3' => '$Gx',
    'FACE4' => '$P\'',
    'FACE5' => '$P&',
    'GOOD' => '$FV',
    'ONPU' => '$G^',
    'ONSEN' => '$EC',
    'MIDASHI' => '$F;',
    'KISS' => '$G#',
    'KIRAKIRA' => '$ON',
    'HINT' => '$E/',
    'ANGER' => '$OT',
    'PUNCH' => '$G-',
    'BOMB' => '$O1',
    'MOOD' => '$OF',
    'BAD' => '$FX',
    'SLEEP' => '$E\\',
    'BIKKURI' => '$GA',
    'QUESTION' => '&#63912;',
    'BIKKURI2' => '&#63913;',
    'DON' => '&#63914;',
    'ASE1' => '$OQ',
    'ASE2' => '$OQ',
    'DASH' => '$OP',
    'SIGN1' => '&#63918;',
    'SIGN2' => '&#63919;',
    'CLAPPERBOARD' => '$OD',
    'FUKURO' => '&#63825;',
    'PEN1' => '$O!',
    'SHADOW' => '&#63829;',
    'CHAIR' => '$E?',
    'NIGHT' => '$Pk',
    'SOON' => '&#63835;',
    'ON' => '&#63836;',
    'END' => '&#63837;',
    'SCHEDULE' => '$GM',
    'IAPP1' => '&#63921;',
    'IAPP2' => '&#63922;',
    'TSHIRT' => '$G&',
    'GAMA' => '&#63924;',
    'MAKEUP' => '$O<',
    'ZUBON' => '&#63926;',
    'SPORTS2' => '&#63927;',
    'TIN' => '$OE',
    'DOOR' => '&#63929;',
    'MONEY' => '$EO',
    'PC' => '$G,',
    'HEARTMAIL' => '$E#$OH',
    'TOOL' => '$E6',
    'PEN2' => '$O!',
    'CROWN' => '$E.',
    'RING' => '$GT',
    'WATCH1' => '&#63937;',
    'BICYCLE' => '$EV',
    'CUP' => '$OX',
    'WATCH2' => '&#63940;',
    'FACE6' => '$P#',
    'FACE7' => '$P*',
    'FACE8' => '$P5$OQ',
    'FACE9' => '$E(',
    'FACE10' => '$P6',
    'FACE11' => '$P.',
    'FACE12' => '$E&',
    'OK2' => '$G.',
    'FACE13' => '$E%',
    'FACE14' => '$P%',
    'FACE15' => '$P*',
    'FACE16' => '$P1',
    'CAT2' => '$P"',
    'FACE17' => '$P3',
    'NG' => '&#63956;',
    'CLIP' => '&#63957;',
    'COPYRIGHT' => '$Fn',
    'TM' => '$QW',
    'RUN' => '$E5',
    'MARUHI' => '$O5',
    'UPDATE' => '$FV',
    'R' => '$Fo',
    'ALERT' => '$Fr',
    'KIN' => '&#63965;',
    'AKI' => '$FK',
    'GOU' => '&#63967;',
    'MAN' => '$FJ',
    'YA5' => '&#63969;',
    'YA6' => '&#63970;',
    'SCHOOL' => '$Ew',
    'WAVE' => '$P^',
    'FUJI' => '$G[',
    'FOURLEAF' => '$E0',
    'CHERRY' => '&#63975;',
    'TULIP' => '$O$',
    'BANANA' => '&#63977;',
    'APPLE' => '$Oe',
    'BUD' => '$E0',
    'MOMIJI' => '$E8',
    'SAKURA' => '$GP',
    'ONIGIRI' => '$Ob',
    'CAKE' => '$Gf',
    'TOKURI' => '$O+',
    'DONBURI' => '$O`',
    'BREAD' => '$OY',
    'SNAIL' => '&#63987;',
    'HIYOKO' => '$QC',
    'PENGIN' => '$Gu',
    'FISH' => '$G9',
    'FACE18' => '$Gv',
    'FACE19' => '$P$',
    'HORSE' => '$G:',
    'PIG' => '$E+',
    'WINE' => '$Gd',
    'FACE20' => '$E\''
);
